#[macro_use]
mod macros;
mod escape_test;
mod fail_test;
mod main_fn_test;
mod spec_test;
